#ifndef TRT_RESIZENEAREST_PLUGIN_HPP
#define TRT_RESIZENEAREST_PLUGIN_HPP

#include <framework/Checks.hpp>
#include <dw/dnn/plugin/DNNPlugin.h>

#include <cudnn.h>
#include <cublas_v2.h>
#include <assert.h>
#include <memory>

class ResizeNearest
{
public:
    ResizeNearest(float scale);

    ResizeNearest(const void* data, size_t length);

    virtual ~ResizeNearest();

    int32_t getNbOutputs() const;

    dwBlobSize getOutputDimensions(int index, const dwBlobSize* inputs, int nbInputDims);

    bool supportsFormat(dwPrecision precision, dwDNNPluginLayout layout) const;

    //void configureWithFormat(dwPrecision precision, dwDNNPluginLayout layout);

    int initialize();

    void terminate();

    virtual size_t getWorkspaceSize(int) const;

    //virtual int enqueue(int batch_size, const void* const* inputs, void** outputs, void* workspace, cudaStream_t stream);

    //virtual size_t getSerializationSize();

    //virtual void serialize(void* buffer);

    static const char* getPluginType()
    {
        return "ResizeNearest";
    }
    static const char* getPluginVersion()
    {
        return "001";
    }

private:
    float mScale;
    dwBlobSize mInputDims;
    dwBlobSize mOutputDims;
    std::string mNameSpace;

    cudnnHandle_t m_cudnn;
    cublasHandle_t m_cublas;
    cudnnTensorDescriptor_t m_srcDescriptor, m_dstDescriptor;

    template<typename T> void read(const char*& buffer, T& val)
    {
        val = *reinterpret_cast<const T*>(buffer);
        buffer += sizeof(T);
    }
};

#endif // TRT_RESIZENEAREST_PLUGIN_H